@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: An algorithmic MIDI drummer
 
-our $VERSION = '0.0804';
+our $VERSION = '0.0805';
 
 use strict;
 use warnings;
@@ -584,12 +584,13 @@ MIDI::Simple::Drummer - An algorithmic MIDI drummer
 
 =head1 VERSION
 
-version 0.0804
+version 0.0805
 
 =head1 SYNOPSIS
 
-  # A glorified metronome:
   use MIDI::Simple::Drummer;
+
+  # A glorified metronome:
   my $d = MIDI::Simple::Drummer->new(-bpm => 100);
   $d->count_in;
   for(1 .. $d->phrases * $d->bars) {
@@ -598,8 +599,7 @@ version 0.0804
   }
 
   # Shuffle:
-  use MIDI::Simple::Drummer;
-  my $d = MIDI::Simple::Drummer->new(-bpm => 100);
+  $d = MIDI::Simple::Drummer->new(-bpm => 100);
   $d->count_in;
   for(1 .. $d->phrases * $d->bars) {
     $d->note($d->TRIPLET_EIGHTH, $d->backbeat_rhythm(-beat => $_));
@@ -609,7 +609,7 @@ version 0.0804
 
   # A rock drummer:
   use MIDI::Simple::Drummer::Rock;
-  my $d = MIDI::Simple::Drummer::Rock->new(
+  $d = MIDI::Simple::Drummer::Rock->new(
     -bpm     => 100,
     -volume  => 100,
     -phrases => 8,
@@ -639,8 +639,7 @@ version 0.0804
   }
 
   # Multi-tracking:
-  use MIDI::Simple::Drummer;
-  my $d = MIDI::Simple::Drummer->new(-file => "$0.mid");
+  $d = MIDI::Simple::Drummer->new(-file => "$0.mid");
   $d->patterns(b1 => \&hihat);
   $d->patterns(b2 => \&backbeat);
   $d->sync_tracks(
@@ -676,7 +675,7 @@ kit elements are named and what the patterns do.  For these things, "Use The
 Source, Luke."  Also, check out the included style sub-classes, the F<eg/*>
 files (and the F<*.mid> files they produce).
 
-The default drum kit is the B<exciting>, General MIDI Kit.  Fortunately, you can
+The default drum kit is the B<exciting> General MIDI Kit.  Fortunately, you can
 import the F<.mid> file into your DAW and reassign better patches.  Using the
 C<-patch> parameter, you can change drum kits (to brushes or TR-808 for
 instance) and also have various extended MIDI voices available.
