@@ -1,9 +1,9 @@
 package MIDI::Simple::Drummer::Euclidean;
+$MIDI::Simple::Drummer::Euclidean::VERSION = '0.0805';
 our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 use parent 'MIDI::Simple::Drummer';
-our $VERSION = '0.0101';
 
 sub new {
     my $self = shift;
@@ -97,23 +97,19 @@ MIDI::Simple::Drummer::Euclidean
 
 =head1 VERSION
 
-version 0.0804
+version 0.0805
 
 =head1 DESCRIPTION
 
 Generate Euclidean rhythms and "world beat" grooves.
 
-=head1 NAME
-
-MIDI::Simple::Drummer::Euclidean - Euclidean Rhythms
-
 =head1 METHODS
 
-=head2 euclid()
+=head2 euclid
 
 Return a list of B<x> onsets or B<.> rests given the C<onsets> and C<beats>.
 
-=head2 rotate()
+=head2 rotate
 
 Rotate the given list of onsets and rests to the next (to the right) onset.
 
